Signed-off-by: Liam R. Howlett <liam.howl...@oracle.com>
---
 mm/huge_memory.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/mm/huge_memory.c b/mm/huge_memory.c
index ec2bb93f74314..4005beb23daf9 100644
--- a/mm/huge_memory.c
+++ b/mm/huge_memory.c
@@ -2304,12 +2304,12 @@ void vma_adjust_trans_huge(struct vm_area_struct *vma,
                split_huge_pmd_address(vma, end, false, NULL);
 
        /*
         * If we're also updating the vma->vm_next->vm_start, if the new
         * vm_next->vm_start isn't hpage aligned and it could previously
         * contain an hugepage: check if we need to split an huge pmd.
         */
        if (adjust_next > 0) {
-               struct vm_area_struct *next = vma->vm_next;
+               struct vm_area_struct *next = vma_next(vma->vm_mm, vma);
                unsigned long nstart = next->vm_start;
                nstart += adjust_next;
                if (nstart & ~HPAGE_PMD_MASK &&
@@ -2304,12 +2304,12 @@ void vma_adjust_trans_huge(struct vm_area_struct *vma,
 
        /*
-        * If we're also updating the vma->vm_next->vm_start, if the new
-        * vm_next->vm_start isn't hpage aligned and it could previously
+        * If we're also updating the vma_next(vma)->vm_start, if the new
+        * vma_next()->vm_start isn't hpage aligned and it could previously
         * contain an hugepage: check if we need to split an huge pmd.
         */
-- 
2.28.0

Reply via email to